@@ -259,6 +259,11 @@ class Actor(IActor):
         self.logger.debug("External Tick end cycle: {}".format(cycle))
 
     def actor_tick(self, *, cycle: int):
+        """
+        Actor Tick
+        :param cycle: cycle
+        :return:
+        """
         try:
             if not self.recovered:
                 self.logger.warning("Tick for an actor that has not completed recovery")
@@ -463,6 +468,8 @@ class Actor(IActor):
             except Exception as e:
                 self.logger.error(traceback.format_exc())
                 self.logger.error("Error in recoverSlice for property list {}".format(e))
+                if s.is_inventory():
+                    raise e
 
     def recover_slice(self, *, slice_obj: ISlice):
         """
@@ -956,4 +963,7 @@ class Actor(IActor):
         if self.policy is not None:
             self.policy.set_logger(logger=logger)
         if self.plugin is not None:
-            self.plugin.set_logger(logger=logger)
\ No newline at end of file
+            self.plugin.set_logger(logger=logger)
+
+    def load_model(self, *, graph_id: str):
+        return
