@@ -30,6 +30,11 @@ from typing import TYPE_CHECKING
 
 from datetime import datetime
 
+from fim.graph.slices.neo4j_asm import Neo4jASMFactory
+from fim.slivers.capacities_labels import ReservationInfo
+from fim.slivers.network_node import NodeSliver
+from fim.user.topology import ExperimentTopology
+
 from fabric_cf.actor.core.apis.i_authority_policy import IAuthorityPolicy
 from fabric_cf.actor.core.apis.i_kernel_controller_reservation import IKernelControllerReservation
 from fabric_cf.actor.core.common.constants import Constants
@@ -45,6 +50,7 @@ from fabric_cf.actor.core.kernel.reservation_states import ReservationPendingSta
 from fabric_cf.actor.core.util.id import ID
 from fabric_cf.actor.core.util.reservation_state import ReservationState
 from fabric_cf.actor.core.util.update_data import UpdateData
+from fabric_cf.actor.fim.fim_helper import FimHelper
 
 if TYPE_CHECKING:
     from fabric_cf.actor.core.apis.i_slice import ISlice
@@ -777,6 +783,9 @@ class ReservationClient(Reservation, IKernelControllerReservation):
                 # If redeem fails we should not fail the reservation!!! The
                 # failure may be due to the authority being unavailable
                 RPCManagerSingleton.get().redeem(reservation=self)
+
+                # Update ASM with Reservation Info
+                self.update_slice_graph(sliver=self.resources.sliver)
         elif self.joinstate == JoinState.BlockedJoin:
             # This reservation has a lease whose join processing was blocked
             # for a predecessor: see if we can get it going now. Note: if
@@ -792,6 +801,10 @@ class ReservationClient(Reservation, IKernelControllerReservation):
                 self.transition_with_join(prefix="unblocked join", state=self.state, pending=self.pending_state,
                                           join_state=JoinState.Joining)
                 self.service_pending = JoinState.Joining
+
+                # Update ASM with Reservation Info
+                self.update_slice_graph(sliver=self.resources.sliver)
+
         elif self.joinstate == JoinState.Joining and self.service_pending == JoinState.None_ and \
                 self.leased_resources.is_active() and not self.pending_recover and\
                 self.state != ReservationStates.ActiveTicketed:
@@ -816,6 +829,9 @@ class ReservationClient(Reservation, IKernelControllerReservation):
                               format(self.leased_resources.get_notices().get_notice()), exception=None)
                 else:
                     self.fail(message="resources failed to join: (no details)", exception=None)
+            else:
+                # Update ASM with Reservation Info
+                self.update_slice_graph(sliver=self.leased_resources.sliver)
 
     def probe_pending(self):
         # Process join state to complete or restart join-related operations for Controller
@@ -912,6 +928,7 @@ class ReservationClient(Reservation, IKernelControllerReservation):
         if self.leased_resources is not None:
             self.logger.debug("Closing leased resources: {}".format(type(self.leased_resources)))
             self.leased_resources.close()
+            self.update_slice_graph(sliver=self.leased_resources.sliver)
 
     def service_probe(self):
         # An exception in one of these service routines should mean some
@@ -936,23 +953,26 @@ class ReservationClient(Reservation, IKernelControllerReservation):
         self.service_pending = JoinState.None_
 
     def service_update_lease(self):
-        if self.leased_resources is not None and self.last_lease_update.successful() and \
-                self.joinstate != JoinState.BlockedJoin:
-            # An update() was called above, so we must clear it. Update()
-            # must be called in every success case, and must not be called
-            # in any failure case. But: if the reservation is in
-            # BlockedJoin, then leave the update unserviced until a future
-            # probePending.
-            self.leased_resources.service_update(reservation=self)
-            self.set_dirty()
+        if self.leased_resources is not None and self.last_lease_update.successful():
+            if self.joinstate != JoinState.BlockedJoin:
+                # An update() was called above, so we must clear it. Update()
+                # must be called in every success case, and must not be called
+                # in any failure case. But: if the reservation is in
+                # BlockedJoin, then leave the update unserviced until a future
+                # probePending.
+                self.leased_resources.service_update(reservation=self)
+                self.set_dirty()
 
-            # If subsequent lease updates come in (e.g., for an extend)
-            # before we have cleared the initial one, then
-            # rset.serviceUpdate should now do the right thing.
+                # If subsequent lease updates come in (e.g., for an extend)
+                # before we have cleared the initial one, then
+                # rset.serviceUpdate should now do the right thing.
+
+                self.update_slice_graph(sliver=self.leased_resources.sliver)
 
     def service_update_ticket(self):
         if self.last_ticket_update.successful():
             self.resources.service_update(reservation=self)
+            self.update_slice_graph(sliver=self.resources.sliver)
 
     def set_broker(self, *, broker: IBrokerProxy) -> bool:
         if self.state != ReservationStates.Nascent:
@@ -1077,7 +1097,6 @@ class ReservationClient(Reservation, IKernelControllerReservation):
                                               state=ReservationStates.Active,
                                               pending=ReservationPendingStates.None_,
                                               join_state=JoinState.Joining)
-
                 self.pending_recover = False
 
             if self.closed_during_redeem:
@@ -1095,6 +1114,7 @@ class ReservationClient(Reservation, IKernelControllerReservation):
 
             self.transition(prefix=self.CLOSE_COMPLETE, state=ReservationStates.Closed,
                             pending=ReservationPendingStates.None_)
+
             self.do_relinquish()
 
         elif self.state == ReservationStates.Closed:
@@ -1455,3 +1475,20 @@ class ReservationClient(Reservation, IKernelControllerReservation):
             self.recover_closing()
         elif self.state == ReservationStates.Failed:
             self.logger.warning("Reservation #{} has failed".format(self.get_reservation_id()))
+
+    def fail(self, *, message: str, exception: Exception = None):
+        super().fail(message=message, exception=exception)
+        self.update_slice_graph(sliver=self.requested_resources.sliver)
+
+    def update_slice_graph(self, *, sliver: NodeSliver):
+        """
+        Update ASM with Sliver information
+        :param sliver: sliver
+        :return:
+        """
+        self.logger.debug(f"Updating ASM for  Reservation# {self.rid} State# {self.get_reservation_state()} "
+                          f"Slice Graph# {self.slice.get_graph_id()}")
+        self.slice.update_slice_graph(sliver=sliver, rid=str(self.rid),
+                                      reservation_state=self.state.name)
+        self.logger.debug(f"Update ASM completed for  Reservation# {self.rid} State# {self.get_reservation_state()} "
+                          f"Slice Graph# {self.slice.get_graph_id()}")
