@@ -194,6 +194,7 @@ class ActorManagementObject(ManagementObject, IActorManagementObject):
                 slice_obj_new.set_owner(owner=self.actor.get_identity())
                 slice_obj_new.get_owner().set_oidc_sub_claim(oidc_sub_claim=user_dn)
                 slice_obj_new.set_graph_id(graph_id=slice_obj.graph_id)
+                slice_obj_new.set_config_properties(value=slice_obj.get_config_properties())
 
                 if slice_obj.get_inventory():
                     slice_obj_new.set_inventory(value=True)
@@ -323,7 +324,7 @@ class ActorManagementObject(ManagementObject, IActorManagementObject):
             res_list = None
             try:
                 if rid is not None:
-                    res = self.db.get_reservation(rid)
+                    res = self.db.get_reservation(rid=rid)
                     if res is not None:
                         res_list = [res]
                     else:
