@@ -42,7 +42,7 @@ from fabric_cf.actor.core.time.calendar.authority_calendar import AuthorityCalen
 from fabric_cf.actor.core.util.id import ID
 from fabric_cf.actor.core.util.reservation_set import ReservationSet
 from fabric_cf.actor.core.util.resource_type import ResourceType
-from fabric_cf.actor.neo4j.neo4j_helper import Neo4jHelper
+from fabric_cf.actor.fim.fim_helper import FimHelper
 
 
 class AuthorityCalendarPolicy(AuthorityPolicy):
@@ -76,7 +76,7 @@ class AuthorityCalendarPolicy(AuthorityPolicy):
             self.logger.debug(f"Loading an existing Aggregate ResourceModel Graph:"
                               f" {self.aggregate_resource_model_graph_id}")
 
-            self.aggregate_resource_model = Neo4jHelper.get_arm_graph(graph_id=self.aggregate_resource_model_graph_id)
+            self.aggregate_resource_model = FimHelper.get_arm_graph(graph_id=self.aggregate_resource_model_graph_id)
             self.logger.debug(f"Successfully loaded an existing Aggregate Resource Model Graph: "
                               f"{self.aggregate_resource_model_graph_id}")
 
@@ -101,6 +101,9 @@ class AuthorityCalendarPolicy(AuthorityPolicy):
         self.clock = None
         self.initialized = False
         self.controls_by_resource_type = {}
+        self.aggregate_resource_model = None
+
+        self.lock = threading.Lock()
         self.restore()
 
     def restore(self):
@@ -113,10 +116,10 @@ class AuthorityCalendarPolicy(AuthorityPolicy):
             except Exception as e:
                 raise AuthorityException(f"Cannot restore resource control e:{e}")
 
-        self.load_aggregate_resource_model()
-
     def set_aggregate_resource_model(self, aggregate_resource_model: Neo4jARMGraph):
         self.aggregate_resource_model = aggregate_resource_model
+        if aggregate_resource_model is not None:
+            self.set_aggregate_resource_model_graph_id(graph_id=aggregate_resource_model.graph_id)
 
     def set_aggregate_resource_model_graph_id(self, graph_id: str):
         self.aggregate_resource_model_graph_id = graph_id
@@ -129,6 +132,7 @@ class AuthorityCalendarPolicy(AuthorityPolicy):
             super().initialize()
             self.calendar = AuthorityCalendar(clock=self.clock)
             self.initialize_controls()
+            self.load_aggregate_resource_model()
             self.initialized = True
 
     def initialize_controls(self):
@@ -362,7 +366,7 @@ class AuthorityCalendarPolicy(AuthorityPolicy):
             approved = reservation.get_requested_term()
             reservation.set_approved(term=approved, approved_resources=assigned)
             reservation.set_bid_pending(value=False)
-            node_id = assigned.get_sliver().bqm_node_id
+            node_id = assigned.get_sliver().get_node_map()[1]
 
             if node_id_to_reservations.get(node_id, None) is None:
                 node_id_to_reservations[node_id] = ReservationSet()
@@ -390,11 +394,13 @@ class AuthorityCalendarPolicy(AuthorityPolicy):
         if rc is not None:
             try:
                 ticketed_sliver = requested.get_sliver()
-                node_id = ticketed_sliver.bqm_node_id
+                node_id = ticketed_sliver.get_node_map()[1]
+                self.logger.debug(f"node_id {node_id} serving reservation# {reservation}")
                 if node_id is None:
                     raise AuthorityException(f"Unable to find node_id {node_id} for reservation# {reservation}")
 
                 graph_node = self.get_node_from_graph(node_id=node_id)
+                self.logger.debug(f"Node {graph_node} serving reservation# {reservation}")
 
                 existing_reservations = self.get_existing_reservations(node_id=node_id,
                                                                        node_id_to_reservations=node_id_to_reservations)
@@ -402,9 +408,9 @@ class AuthorityCalendarPolicy(AuthorityPolicy):
                 delegation_name = self.get_delegation_name(delegation_id=requested.get_resources().get_delegation_id())
 
                 rset = rc.assign(reservation=reservation, delegation_name=delegation_name,
-                                 graph_node=graph_node, reservation_info=existing_reservations)
+                                 graph_node=graph_node, existing_reservations=existing_reservations)
 
-                if rset is None or rset.get_sliver() is None or rset.get_sliver().bqm_node_id is None:
+                if rset is None or rset.get_sliver() is None or rset.get_sliver().get_node_map() is None:
                     raise AuthorityException(f"Could not assign resources to reservation# {reservation}")
 
                 return rset
